@@ -1,20 +1,8 @@
 /*
 
-  Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef MAILCOMMON_EXPIRECOLLECTIONATTRIBUTE_H
@@ -50,9 +38,9 @@ public:
         ExpireMove = 1
     };
 
-    QByteArray type() const override;
+    Q_REQUIRED_RESULT QByteArray type() const override;
     ExpireCollectionAttribute *clone() const override;
-    QByteArray serialized() const override;
+    Q_REQUIRED_RESULT QByteArray serialized() const override;
     void deserialize(const QByteArray &data) override;
 
     void daysToExpire(int &unreadDays, int &readDays) const;
@@ -65,7 +53,7 @@ public:
     /**
      * Returns true if this folder automatically expires old messages.
      */
-    bool isAutoExpire() const;
+    Q_REQUIRED_RESULT bool isAutoExpire() const;
 
     /**
      * Sets the maximum age for unread messages in this folder.
@@ -97,18 +85,18 @@ public:
      * Returns the age at which unread messages are expired.
      * Units are determined by unreadExpireUnits().
      */
-    int unreadExpireAge() const;
+    Q_REQUIRED_RESULT int unreadExpireAge() const;
 
     /**
      * Returns the age at which read messages are expired.
      * Units are determined by readExpireUnits().
      */
-    int readExpireAge() const;
+    Q_REQUIRED_RESULT int readExpireAge() const;
 
     /**
      * What should expiry do? Delete or move to another folder?
      */
-    ExpireAction expireAction() const;
+    Q_REQUIRED_RESULT ExpireAction expireAction() const;
     void setExpireAction(ExpireAction a);
 
     /**
@@ -121,24 +109,28 @@ public:
      * Units getUnreadExpireAge() is returned in.
      * 1 = days, 2 = weeks, 3 = months.
      */
-    ExpireUnits unreadExpireUnits() const;
+    Q_REQUIRED_RESULT ExpireUnits unreadExpireUnits() const;
 
     /**
      * Units getReadExpireAge() is returned in.
      * 1 = days, 2 = weeks, 3 = months.
      */
-    ExpireUnits readExpireUnits() const;
+    Q_REQUIRED_RESULT ExpireUnits readExpireUnits() const;
 
     bool operator==(const ExpireCollectionAttribute &other) const;
+    Q_REQUIRED_RESULT bool expireMessagesWithValidDate() const;
+    void setExpireMessagesWithValidDate(bool expireMessagesWithValidDate);
+
 private:
     static int daysToExpire(int number, ExpireCollectionAttribute::ExpireUnits units);
-    bool mExpireMessages;         // true if old messages are expired
-    int mUnreadExpireAge;         // Given in unreadExpireUnits
-    int mReadExpireAge;           // Given in readExpireUnits
-    ExpireCollectionAttribute::ExpireUnits mUnreadExpireUnits;
-    ExpireCollectionAttribute::ExpireUnits mReadExpireUnits;
-    ExpireCollectionAttribute::ExpireAction mExpireAction;
-    Akonadi::Collection::Id mExpireToFolderId;
+    bool mExpireMessages = false;         // true if old messages are expired
+    int mUnreadExpireAge = 28;         // Given in unreadExpireUnits
+    int mReadExpireAge = 14;           // Given in readExpireUnits
+    ExpireCollectionAttribute::ExpireUnits mUnreadExpireUnits = ExpireNever;
+    ExpireCollectionAttribute::ExpireUnits mReadExpireUnits = ExpireNever;
+    ExpireCollectionAttribute::ExpireAction mExpireAction = ExpireDelete;
+    Akonadi::Collection::Id mExpireToFolderId = -1;
+    bool mExpireMessagesWithValidDate = false;
 };
 }
 MAILCOMMON_EXPORT QDebug operator <<(QDebug d, const MailCommon::ExpireCollectionAttribute &t);
