@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filteractionwithurltest.h"
@@ -53,9 +42,9 @@ void FilterActionWithUrlTest::shouldHaveDefaultValue()
 {
     TestFilterActionWithUrl filter;
     QWidget *w = filter.createParamWidget(nullptr);
-    KUrlRequester *requester = w->findChild<KUrlRequester *>(QStringLiteral("requester"));
+    auto *requester = w->findChild<KUrlRequester *>(QStringLiteral("requester"));
     QVERIFY(requester);
-    QToolButton *toolButton = w->findChild<QToolButton *>(QStringLiteral("helpbutton"));
+    auto *toolButton = w->findChild<QToolButton *>(QStringLiteral("helpbutton"));
     QVERIFY(toolButton);
 }
 
@@ -63,7 +52,7 @@ void FilterActionWithUrlTest::shouldClearWidget()
 {
     TestFilterActionWithUrl filter;
     QWidget *w = filter.createParamWidget(nullptr);
-    KUrlRequester *requester = w->findChild<KUrlRequester *>(QStringLiteral("requester"));
+    auto *requester = w->findChild<KUrlRequester *>(QStringLiteral("requester"));
     requester->setUrl(QUrl::fromLocalFile(QStringLiteral("/foo/bla")));
     QVERIFY(!requester->url().isEmpty());
     filter.clearParamWidget(w);
@@ -74,7 +63,7 @@ void FilterActionWithUrlTest::shouldAddValue()
 {
     TestFilterActionWithUrl filter;
     QWidget *w = filter.createParamWidget(nullptr);
-    KUrlRequester *requester = w->findChild<KUrlRequester *>(QStringLiteral("requester"));
+    auto *requester = w->findChild<KUrlRequester *>(QStringLiteral("requester"));
     filter.argsFromString(QStringLiteral("/foo"));
     filter.setParamWidgetValue(w);
     QCOMPARE(requester->lineEdit()->text(), QStringLiteral("/foo"));
@@ -98,7 +87,7 @@ void FilterActionWithUrlTest::shouldTestUrl_data()
     QTest::newRow("local") <<  QStringLiteral("ls") << QStringLiteral("ls");
     QTest::newRow("localwithargument") <<  QStringLiteral("ls -l") << QStringLiteral("ls -l");
     QTest::newRow("fullpathwithargument") <<  QStringLiteral("/usr/bin/ls -l") << QStringLiteral("/usr/bin/ls -l");
-    QTest::newRow("url") <<  QStringLiteral("file:///usr/bin/ls -l") << QStringLiteral("/usr/bin/ls -l");
+    QTest::newRow("url") <<  QStringLiteral("file:///usr/bin/ls -l") << QStringLiteral("file:///usr/bin/ls -l");
     QTest::newRow("url2") <<  QStringLiteral("/usr/bin/ls -l") << QStringLiteral("/usr/bin/ls -l");
 }
 
