@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -21,7 +9,6 @@
 #include "filter/filtermanager.h"
 #include "filter/dialog/filteractionmissingtagdialog.h"
 
-#include <QPointer>
 #include <QComboBox>
 
 #include <AkonadiCore/Tag>
@@ -52,11 +39,7 @@ QWidget *FilterActionAddTag::createParamWidget(QWidget *parent) const
     }
 
     setParamWidgetValue(mComboBox);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &FilterActionAddTag::filterActionModified);
-#else
-    connect(mComboBox, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &FilterActionAddTag::filterActionModified);
-#endif
 
     return mComboBox;
 }
