@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -57,11 +45,11 @@ bool FilterActionWithUrl::isEmpty() const
 QWidget *FilterActionWithUrl::createParamWidget(QWidget *parent) const
 {
     QWidget *widget = new QWidget(parent);
-    QHBoxLayout *layout = new QHBoxLayout;
+    auto *layout = new QHBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     widget->setLayout(layout);
-    KUrlRequester *requester = new KUrlRequester(parent);
+    auto *requester = new KUrlRequester(parent);
     requester->setUrl(QUrl::fromLocalFile(mParameter));
     requester->setObjectName(QStringLiteral("requester"));
     layout->addWidget(requester);
@@ -83,7 +71,7 @@ void FilterActionWithUrl::slotHelp()
 
 void FilterActionWithUrl::applyParamWidgetValue(QWidget *paramWidget)
 {
-    KUrlRequester *requester = paramWidget->findChild<KUrlRequester *>(QStringLiteral("requester"));
+    auto *requester = paramWidget->findChild<KUrlRequester *>(QStringLiteral("requester"));
     Q_ASSERT(requester);
 
     mParameter = requester->text();
@@ -91,7 +79,7 @@ void FilterActionWithUrl::applyParamWidgetValue(QWidget *paramWidget)
 
 void FilterActionWithUrl::setParamWidgetValue(QWidget *paramWidget) const
 {
-    KUrlRequester *requester = paramWidget->findChild<KUrlRequester *>(QStringLiteral("requester"));
+    auto *requester = paramWidget->findChild<KUrlRequester *>(QStringLiteral("requester"));
     Q_ASSERT(requester);
 
     requester->setText(mParameter);
@@ -99,7 +87,7 @@ void FilterActionWithUrl::setParamWidgetValue(QWidget *paramWidget) const
 
 void FilterActionWithUrl::clearParamWidget(QWidget *paramWidget) const
 {
-    KUrlRequester *requester = paramWidget->findChild<KUrlRequester *>(QStringLiteral("requester"));
+    auto *requester = paramWidget->findChild<KUrlRequester *>(QStringLiteral("requester"));
     Q_ASSERT(requester);
     requester->clear();
 }
