@@ -1,30 +1,7 @@
 /*
-  Copyright (c) 2007 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2007 Till Adam <adam@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt.  If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filterimporterexporter.h"
@@ -68,7 +45,7 @@ QVector<MailFilter *> FilterImporterExporter::readFiltersFromConfig(
 
         const KConfigGroup group = config->group(groupName);
         bool update = false;
-        MailFilter *filter = new MailFilter(group, true /*interactive*/, update);
+        auto *filter = new MailFilter(group, true /*interactive*/, update);
         filter->purify();
         if (update) {
             filterNeedUpdate = true;
@@ -253,7 +230,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(
                             i18n("The selected file is not readable. "
                                  "Your file access permissions might be insufficient."));
                     } else {
-                        MailCommon::FilterImporterThunderbird *thunderBirdFilter
+                        auto *thunderBirdFilter
                             = new MailCommon::FilterImporterThunderbird(&fileThunderbird);
 
                         imported.append(thunderBirdFilter->importFilter());
@@ -277,7 +254,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(
                 return QVector<MailFilter *>();
             }
 
-            MailCommon::FilterImporterThunderbird *thunderBirdFilter = new MailCommon::FilterImporterThunderbird(&file);
+            auto *thunderBirdFilter = new MailCommon::FilterImporterThunderbird(&file);
             imported = thunderBirdFilter->importFilter();
             emptyFilter = thunderBirdFilter->emptyFilter();
             delete thunderBirdFilter;
@@ -285,7 +262,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(
         break;
     case EvolutionFilter:
     {
-        MailCommon::FilterImporterEvolution *filter
+        auto *filter
             = new MailCommon::FilterImporterEvolution(&file);
 
         imported = filter->importFilter();
@@ -295,7 +272,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(
     }
     case SylpheedFilter:
     {
-        MailCommon::FilterImporterSylpheed *filter
+        auto *filter
             = new MailCommon::FilterImporterSylpheed(&file);
 
         imported = filter->importFilter();
@@ -305,7 +282,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(
     }
     case ProcmailFilter:
     {
-        MailCommon::FilterImporterProcmail *filter
+        auto *filter
             = new MailCommon::FilterImporterProcmail(&file);
 
         imported = filter->importFilter();
@@ -315,7 +292,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(
     }
     case BalsaFilter:
     {
-        MailCommon::FilterImporterBalsa *filter
+        auto *filter
             = new MailCommon::FilterImporterBalsa(&file);
 
         imported = filter->importFilter();
@@ -325,7 +302,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(
     }
     case ClawsMailFilter:
     {
-        MailCommon::FilterImporterClawsMails *filter
+        auto *filter
             = new MailCommon::FilterImporterClawsMails(&file);
 
         imported = filter->importFilter();
@@ -335,7 +312,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(
     }
     case GmailFilter:
     {
-        MailCommon::FilterImporterGmail *filter
+        auto *filter
             = new MailCommon::FilterImporterGmail(&file);
 
         imported = filter->importFilter();
